##
##  lynx.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg   2.9.1
%define       V_dist   2.9.1
%define       V_subdir 2.9.1

#   package information
Name:         lynx
Summary:      Interactive Full-Screen Client for HTTP/HTTPS/FTP
URL:          http://lynx.invisible-island.net/release/
Vendor:       Lynx Developers Group, Thomas E. Dickey
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Web
License:      GPL
Version:      %{V_opkg}
Release:      20240418

#   package options
%option       with_ssl  yes
%option       with_cgi  no

#   list of sources
Source0:      https://invisible-mirror.net/archives/lynx/tarballs/lynx%{V_dist}.tar.bz2

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  slang >= 2.0, zlib, bzip2
PreReq:       slang >= 2.0, zlib, bzip2
%if "%{with_ssl}" == "yes"
BuildPreReq:  openssl
PreReq:       openssl
%endif

%description
    Lynx is a text browser for the World Wide Web.
    It supports the protocols HTTP, HTTPS and FTP.

%track
    prog lynx = {
        version   = %{V_dist}
        url       = http://lynx.invisible-island.net/release/
        regex     = lynx(__VER__)\.tar\.bz2
    }

%prep
    %setup -q -n lynx%{V_subdir}

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --sysconfdir=%{l_prefix}/etc/lynx \
        --libdir=%{l_prefix}/etc/lynx \
        --disable-trace \
        --disable-nls \
        --with-screen=slang \
%if "%{with_ssl}" == "yes"
        --with-ssl=%{l_prefix} \
%else
        --without-ssl \
%endif
%if "%{with_cgi}" == "yes"
        --enable-cgi-links \
%else
        --disable-cgi-links \
%endif
        --enable-default-colors \
        --enable-prettysrc \
        --enable-read-eta \
        --enable-scrollbar \
        --enable-nested-tables \
        --with-bzlib \
        --with-zlib
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* 2>/dev/null || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/lynx/*'

%files -f files

%clean

